==> web-7.0.0.tgz: package/lib/table/TBody.js <==
import * as React from "react";
import { CheckBox } from "../input/index";
const TdCheckBox = ({ changeFn, index, checked }) => {
    return (React.createElement(CheckBox, { checked: checked, value: index, type: "checkbox", changeHandle: changeFn }));
};
class TBody extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.isSame = "";
        this.rowSpanNum = 0;
        this.checkFn = (e) => {
            const dom = e.currentTarget;
            const value = dom.value;
            const checked = dom.checked;
            const { tableData, changeHandle } = this.props;
            const newData = tableData.setIn([value, "checked"], checked);
            changeHandle("tableData", newData);
        };
    }
    getCheckCom(checkbox) {
        return checkbox ? TdCheckBox : () => React.createElement(React.Fragment, null);
    }
    getTrCom(dataItem, startIndex, index, curData) {
        const order = `${startIndex + 1 + index}`;
        const { fileObj, selectfn } = this.props;
        const { column, tabField } = fileObj;
        return column.map(node => {
            const { field, formatter, isRowSpanField, align = "center", } = node;
            const text = formatter
                ? formatter(dataItem, order, tabField)
                : dataItem.get(field);
            if (isRowSpanField) {
                const textName = dataItem.get(field);
                if (this.isSame !== textName) {
                    this.isSame = textName;
                    if (this.rowSpanNum < 2) {
                        let countRowSpan = 1;
                        curData.slice(index + 1).findIndex((val) => {
                            const status = val.get(field) !== this.isSame;
                            if (!status) {
                                countRowSpan++;
                            }
                            return status;
                        });
                        this.rowSpanNum = countRowSpan;
                    }
                    return (React.createElement("td", { key: field, className: `td-${align}`, rowSpan: this.rowSpanNum }, text));
                }
                else {
                    this.rowSpanNum = 0;
                    return undefined;
                }
            }
            else {
                return (React.createElement("td", { key: field, className: `td-${align}`, "data-index": order, onClick: field === "opt" ? selectfn : undefined }, text));
            }
        });
    }
    render() {
        const { perNums, curPage, fileObj, tableData } = this.props;
        const { idField, checkbox, noPageNums } = fileObj;
        const startIndex = (curPage - 1) * perNums;
        const curData = (!noPageNums
            ? tableData.slice(startIndex, startIndex + perNums)
            : tableData);
        const CheckBoxOrNull = this.getCheckCom(checkbox);
        const tBody = curData.map((dataItem, index) => {
            const order = `${startIndex + 1 + index}`;
            const checked = dataItem.get("checked");
            const selected = dataItem.get("selected");
            const selectName = selected ? "selected" : undefined;
            const trCom = this.getTrCom(dataItem, startIndex, index, curData);
            return (React.createElement("tr", { key: dataItem.get(idField), className: selectName },
                React.createElement("td", { className: "td-left" },
                    React.createElement("span", null,
                        React.createElement(CheckBoxOrNull, { checked: checked, changeFn: this.checkFn, index: `${index + startIndex}` }),
                        order)),
                trCom));
        });
        this.isSame = "";
        return tBody;
    }
}
export default TBody;

==> web-9.0.0.tgz: package/lib/table/TBody.js <==
import * as React from "react";
import { CheckBox } from "../input/index";
const TdCheckBox = ({ changeFn, index, checked }) => {
    return (React.createElement(CheckBox, { checked: checked, value: index, type: "checkbox", changeHandle: changeFn }));
};
class TBody extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.isSame = "";
        this.rowSpanNum = 0;
        this.checkFn = (e) => {
            const dom = e.currentTarget;
            const value = dom.value;
            const checked = dom.checked;
            const { tableData, changeHandle } = this.props;
            const newData = tableData.setIn([value, "checked"], checked);
            changeHandle("tableData", newData);
        };
    }
    getCheckCom(checkbox) {
        return checkbox ? TdCheckBox : () => React.createElement(React.Fragment, null);
    }
    getTrCom(dataItem, startIndex, index, curData) {
        const order = `${startIndex + 1 + index}`;
        const { fileObj, selectfn } = this.props;
        const { column, tabField } = fileObj;
        return column.map(node => {
            const { field, formatter, isRowSpanField, align = "td-left", } = node;
            const text = formatter
                ? formatter(dataItem, order, tabField)
                : dataItem.get(field);
            if (isRowSpanField) {
                const textName = dataItem.get(field);
                if (this.isSame !== textName) {
                    this.isSame = textName;
                    if (this.rowSpanNum < 2) {
                        let countRowSpan = 1;
                        curData.slice(index + 1).findIndex((val) => {
                            const status = val.get(field) !== this.isSame;
                            if (!status) {
                                countRowSpan++;
                            }
                            return status;
                        });
                        this.rowSpanNum = countRowSpan;
                    }
                    return (React.createElement("td", { key: field, className: `${align}`, rowSpan: this.rowSpanNum }, text));
                }
                else {
                    this.rowSpanNum = 0;
                    return undefined;
                }
            }
            else {
                return (React.createElement("td", { key: field, "data-field": field, className: `${align}`, "data-index": order, onClick: field === "opt" ? selectfn : undefined }, text));
            }
        });
    }
    render() {
        const { perNums, curPage, fileObj, tableData } = this.props;
        const { idField, checkbox, noPageNums } = fileObj;
        const startIndex = (curPage - 1) * perNums;
        const curData = (!noPageNums
            ? tableData.slice(startIndex, startIndex + perNums)
            : tableData);
        const CheckBoxOrNull = this.getCheckCom(checkbox);
        const tBody = curData.map((dataItem, index) => {
            const order = `${startIndex + 1 + index}`;
            const checked = dataItem.get("checked");
            const selected = dataItem.get("selected");
            const selectName = selected ? "selected" : undefined;
            const trCom = this.getTrCom(dataItem, startIndex, index, curData);
            return (React.createElement("tr", { key: dataItem.get(idField), className: selectName },
                React.createElement("td", { className: "td-left" },
                    React.createElement("span", null,
                        React.createElement(CheckBoxOrNull, { checked: checked, changeFn: this.checkFn, index: `${index + startIndex}` }),
                        order)),
                trCom));
        });
        this.isSame = "";
        return tBody;
    }
}
export default TBody;
